==> server-0.2.0-sources.jar: com/xebialabs/xltest/serialize/BasicMessageBodyWriter.java <==
package com.xebialabs.xltest.serialize;

import com.xebialabs.xltest.domain.TestSetDefinition;
import org.codehaus.jettison.json.JSONException;
import org.codehaus.jettison.json.JSONWriter;

import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.MultivaluedMap;
import javax.ws.rs.ext.MessageBodyWriter;
import java.io.IOException;
import java.io.OutputStream;
import java.io.StringWriter;
import java.lang.annotation.Annotation;
import java.lang.reflect.Type;

public abstract class BasicMessageBodyWriter<T> implements MessageBodyWriter<T> {
    @Override
    public final boolean isWriteable(Class<?> aClass, Type type, Annotation[] annotations, MediaType mediaType) {
        return true;
    }

    @Override
    public final long getSize(T instance, Class<?> aClass, Type type, Annotation[] annotations, MediaType mediaType) {
        return -1L;
    }

    @Override
    public final void writeTo(T instance, Class<?> aClass, Type type, Annotation[] annotations, MediaType mediaType, MultivaluedMap<String, Object> httpHeaders, OutputStream outputStream) throws IOException, WebApplicationException {
        try {
            outputStream.write(toJson(instance).getBytes());
        } catch (JSONException e) {
            throw new WebApplicationException(e, 400);
        }
    }

    final String toJson(T instance) throws JSONException {
        StringWriter stringWriter = new StringWriter();
        JSONWriter writer = new JSONWriter(stringWriter);
        writeJson(instance, writer);
        return stringWriter.toString();
    }

    protected abstract void writeJson(T instance, JSONWriter writer) throws JSONException;
}

==> server-1.0.0-sources.jar: com/xebialabs/xltest/serialize/BasicMessageBodyWriter.java <==
package com.xebialabs.xltest.serialize;

import java.io.IOException;
import java.io.OutputStream;
import java.io.StringWriter;
import java.lang.annotation.Annotation;
import java.lang.reflect.Type;

import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.MultivaluedMap;
import javax.ws.rs.ext.MessageBodyWriter;

import org.codehaus.jettison.json.JSONException;
import org.codehaus.jettison.json.JSONWriter;

public abstract class BasicMessageBodyWriter<T> implements MessageBodyWriter<T> {

    @Override
    public boolean isWriteable(Class<?> aClass, Type type, Annotation[] annotations, MediaType mediaType) {
        return true;
    }

    @Override
    public final long getSize(T instance, Class<?> aClass, Type type, Annotation[] annotations, MediaType mediaType) {
        return -1L;
    }

    @Override
    public final void writeTo(T instance, Class<?> aClass, Type type, Annotation[] annotations, MediaType mediaType, MultivaluedMap<String, Object> httpHeaders, OutputStream outputStream) throws IOException, WebApplicationException {
        try {
            outputStream.write(toJson(instance).getBytes());
        } catch (JSONException e) {
            throw new WebApplicationException(e, 400);
        }
    }

    final String toJson(T instance) throws JSONException {
        StringWriter stringWriter = new StringWriter();
        JSONWriter writer = new JSONWriter(stringWriter);
        writeJson(instance, writer);
        return stringWriter.toString();
    }

    protected abstract void writeJson(T instance, JSONWriter writer) throws JSONException;
}
